;; -*- mode: lisp; coding: utf-8; -*-
;; Copyright (C) 2003, 2004
;;   National Institute of Advanced Industrial Science and Technology (AIST)
;;   Registration Number H15PRO112

;; This file is part of the m17n database; a sub-part of the m17n
;; library.

;; The m17n library is free software; you can redistribute it and/or
;; modify it under the terms of the GNU Lesser General Public License
;; as published by the Free Software Foundation; either version 2.1 of
;; the License, or (at your option) any later version.

;; The m17n library is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; Lesser General Public License for more details.

;; You should have received a copy of the GNU Lesser General Public
;; License along with the m17n library; if not, write to the Free
;; Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;; locale vs default codeset:
;; The format of elements is (LOCAL-NAME CODESET-NAME).
;; CODESET-NAME is case insensitve.

(af_ZA iso-8859-1)
(ar_AE iso-8859-6)
(ar_BH iso-8859-6)
(ar_DZ iso-8859-6)
(ar_EG iso-8859-6)
(ar_IN utf-8)
(ar_IQ iso-8859-6)
(ar_JO iso-8859-6)
(ar_KW iso-8859-6)
(ar_LB iso-8859-6)
(ar_LY iso-8859-6)
(ar_MA iso-8859-6)
(ar_OM iso-8859-6)
(ar_QA iso-8859-6)
(ar_SA iso-8859-6)
(ar_SD iso-8859-6)
(ar_SY iso-8859-6)
(ar_TN iso-8859-6)
(ar_YE iso-8859-6)
(be_BY cp1251)
(bg_BG cp1251)
(br_FR iso-8859-1)
(bs_BA iso-8859-2)
(ca_ES iso-8859-1)
(ca_ES@euro iso-8859-15)
(cs_CZ iso-8859-2)
(cy_GB iso-8859-14)
(da_DK iso-8859-1)
(de_AT iso-8859-1)
(de_AT@euro iso-8859-15)
(de_BE iso-8859-1)
(de_BE@euro iso-8859-15)
(de_CH iso-8859-1)
(de_DE iso-8859-1)
(de_DE utf-8)
(de_DE@euro iso-8859-15)
(de_LU iso-8859-1)
(de_LU@euro iso-8859-15)
(el_GR iso-8859-7)
(el_GR utf-8)
(en_AU iso-8859-1)
(en_BW iso-8859-1)
(en_CA iso-8859-1)
(en_DK iso-8859-1)
(en_GB iso-8859-1)
(en_GB utf-8)
(en_HK iso-8859-1)
(en_IE iso-8859-1)
(en_IE@euro iso-8859-15)
(en_IN utf-8)
(en_NZ iso-8859-1)
(en_PH iso-8859-1)
(en_SG iso-8859-1)
(en_US iso-8859-1)
(en_US utf-8)
(en_ZA iso-8859-1)
(en_ZW iso-8859-1)
(es_AR iso-8859-1)
(es_BO iso-8859-1)
(es_CL iso-8859-1)
(es_CO iso-8859-1)
(es_CR iso-8859-1)
(es_DO iso-8859-1)
(es_EC iso-8859-1)
(es_ES iso-8859-1)
(es_ES@euro iso-8859-15)
(es_GT iso-8859-1)
(es_HN iso-8859-1)
(es_MX iso-8859-1)
(es_NI iso-8859-1)
(es_PA iso-8859-1)
(es_PE iso-8859-1)
(es_PR iso-8859-1)
(es_PY iso-8859-1)
(es_SV iso-8859-1)
(es_US iso-8859-1)
(es_UY iso-8859-1)
(es_VE iso-8859-1)
(et_EE iso-8859-1)
(eu_ES iso-8859-1)
(eu_ES@euro iso-8859-15)
(fa_IR utf-8)
(fi_FI iso-8859-1)
(fi_FI@euro iso-8859-15)
(fo_FO iso-8859-1)
(fr_BE iso-8859-1)
(fr_BE@euro iso-8859-15)
(fr_CA iso-8859-1)
(fr_CH iso-8859-1)
(fr_FR iso-8859-1)
(fr_FR utf-8)
(fr_FR@euro iso-8859-15)
(fr_LU iso-8859-1)
(fr_LU@euro iso-8859-15)
(ga_IE iso-8859-1)
(ga_IE@euro iso-8859-15)
(gl_ES iso-8859-1)
(gl_ES@euro iso-8859-15)
(gv_GB iso-8859-1)
(he_IL iso-8859-8)
(hi_IN utf-8)
(hr_HR iso-8859-2)
(hu_HU iso-8859-2)
(id_ID iso-8859-1)
(is_IS iso-8859-1)
(it_CH iso-8859-1)
(it_IT iso-8859-1)
(it_IT@euro iso-8859-15)
(iw_IL iso-8859-8)
(ja_JP euc-jp)
(ja_JP utf-8)
(ka_GE georgian-ps)
(kl_GL iso-8859-1)
(ko_KR euc-kr)
(ko_KR utf-8)
(kw_GB iso-8859-1)
(lt_LT iso-8859-13)
(lv_LV iso-8859-13)
(mi_NZ iso-8859-13)
(mk_MK iso-8859-5)
(mr_IN utf-8)
(ms_MY iso-8859-1)
(mt_MT iso-8859-3)
(nl_BE iso-8859-1)
(nl_BE@euro iso-8859-15)
(nl_NL iso-8859-1)
(nl_NL@euro iso-8859-15)
(nn_NO iso-8859-1)
(no_NO iso-8859-1)
(oc_FR iso-8859-1)
(pl_PL iso-8859-2)
(pt_BR iso-8859-1)
(pt_PT iso-8859-1)
(pt_PT@euro iso-8859-15)
(ro_RO iso-8859-2)
(ru_RU iso-8859-5)
(ru_RU utf-8)
(ru_UA koi8-u)
(sk_SK iso-8859-2)
(sl_SI iso-8859-2)
(sq_AL iso-8859-1)
(sr_YU iso-8859-2)
(sr_YU@cyrillic iso-8859-5)
(sv_FI iso-8859-1)
(sv_FI@euro iso-8859-15)
(sv_SE iso-8859-1)
(ta_IN utf-8)
(te_IN utf-8)
(tg_TJ koi8-t)
(th_TH tis-620)
(tl_PH iso-8859-1)
(tr_TR iso-8859-9)
(uk_UA koi8-u)
(ur_PK utf-8)
(uz_UZ iso-8859-1)
(vi_VN utf-8)
(yi_US cp1255)
(zh_CN gb2312)
(zh_HK big5-hkscs)
(zh_TW big5)
